# ir-metrics [![Build Status](https://travis-ci.com/kqf/ir-metrics.svg?branch=master)](https://travis-ci.com/kqf/ir-metrics)

A set of the most common metrics in used in inforation retrieval.


## Installation
To install with pip, run:

```
pip install ir-metrics
```
